.. toxins documentation master file, created by
   sphinx-quickstart on Sat Apr  2 15:02:58 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to toxins's documentation!
==================================
Toxins is a template for tox-based python projects. It provides some tools:
* ``txclean`` a program to clean source directories from .pyc files left by py.test
* ``txredirect`` a program to redirect the command output to files
* ``txcopy`` a program to copy files or directory trees

Contents:

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

